[tor-commits] [tor/master] Refetch an HS's desc if we don't have a usable one

nickm at torproject.org nickm at torproject.org
Mon Oct 3 19:14:00 UTC 2011


commit 6803c1c371b9cfea30c32dc9eaf3f976614a103c
Author: Robert Ransom <rransom.8774 at gmail.com>
Date:   Wed Sep 28 20:00:24 2011 -0700

    Refetch an HS's desc if we don't have a usable one
    
    Previously, we wouldn't refetch an HS's descriptor unless we didn't
    have one at all.  That was equivalent to refetching iff we didn't have
    a usable one, but the next commit will make us keep some non-usable HS
    descriptors around in our cache.
    
    Code bugfix on the release that introduced the v2 HS directory system,
    because rend_client_refetch_v2_renddesc's documentation comment should
    have described what it actually did, not what its behaviour happened
    to be equivalent to; no behaviour change in this commit.
---
 src/or/rendclient.c |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/src/or/rendclient.c b/src/or/rendclient.c
index 533dfb8..773ac8d 100644
--- a/src/or/rendclient.c
+++ b/src/or/rendclient.c
@@ -574,10 +574,11 @@ rend_client_refetch_v2_renddesc(const rend_data_t *rend_query)
         "service descriptor, but are not fetching service descriptors.");
     return;
   }
-  /* Before fetching, check if we already have the descriptor here. */
-  if (rend_cache_lookup_entry(rend_query->onion_address, -1, &e) > 0) {
+  /* Before fetching, check if we already have a usable descriptor here. */
+  if (rend_cache_lookup_entry(rend_query->onion_address, -1, &e) > 0 &&
+      rend_client_any_intro_points_usable(e)) {
     log_info(LD_REND, "We would fetch a v2 rendezvous descriptor, but we "
-                      "already have that descriptor here. Not fetching.");
+                      "already have a usable descriptor here. Not fetching.");
     return;
   }
   log_debug(LD_REND, "Fetching v2 rendezvous descriptor for service %s",





More information about the tor-commits mailing list